.. image:: https://img.shields.io/pypi/v/jaraco.home.svg
   :target: `PyPI link`_

.. image:: https://img.shields.io/pypi/pyversions/jaraco.home.svg
   :target: `PyPI link`_

.. _PyPI link: https://pypi.org/project/jaraco.home

.. image:: https://github.com/jaraco/jaraco.home/workflows/tests/badge.svg
   :target: https://github.com/jaraco/jaraco.home/actions?query=workflow%3A%22tests%22
   :alt: tests

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/psf/black
   :alt: Code style: Black

.. image:: https://readthedocs.org/projects/jaracohome/badge/?version=latest
   :target: https://jaracohome.readthedocs.io/en/latest/?badge=latest
